@@ -158,7 +158,8 @@ row_has_title (AdwPreferencesRow *row,
 {
   const char *title;
 
-  g_assert (ADW_IS_PREFERENCES_ROW (row));
+  if (!ADW_IS_PREFERENCES_ROW (row))
+    return false;
 
   if (!gtk_widget_get_visible (GTK_WIDGET (row)))
     return FALSE;
@@ -391,7 +392,7 @@ adw_preferences_group_add (AdwPreferencesGroup *self,
 
   priv = adw_preferences_group_get_instance_private (self);
 
-  if (ADW_IS_PREFERENCES_ROW (child))
+  if (GTK_IS_LIST_BOX_ROW (child))
     gtk_list_box_append (priv->listbox, child);
   else
     gtk_box_append (priv->listbox_box, child);
@@ -426,6 +427,32 @@ adw_preferences_group_remove (AdwPreferencesGroup *self,
     ADW_CRITICAL_CANNOT_REMOVE_CHILD (self, child);
 }
 
+/**
+ * adw_preferences_group_get_row:
+ * @self: a preferences group
+ * @index: a row index
+ *
+ * Gets the row at @index.
+ *
+ * Can return `NULL` if @index is larger than the number of rows in the group.
+ *
+ * Returns: (transfer none) (nullable): the row at @index
+ *
+ * Since: 1.8
+ */
+GtkWidget *
+adw_preferences_group_get_row (AdwPreferencesGroup *self,
+                               guint                index)
+{
+  AdwPreferencesGroupPrivate *priv;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_GROUP (self), NULL);
+
+  priv = adw_preferences_group_get_instance_private (self);
+
+  return GTK_WIDGET (gtk_list_box_get_row_at_index (priv->listbox, index));
+}
+
 /**
  * adw_preferences_group_get_title:
  * @self: a preferences group
@@ -646,6 +673,39 @@ adw_preferences_group_set_separate_rows (AdwPreferencesGroup *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SEPARATE_ROWS]);
 }
 
+/**
+ * adw_preferences_group_bind_model:
+ * @self: a preferences group
+ * @model: (nullable): a list model to bind
+ * @create_row_func: (nullable) (scope notified) (closure user_data) (destroy user_data_free_func):
+ *   a function creating a row for each item, or `NULL` in case @model is `NULL`
+ * @user_data: user data passed to @create_row_func
+ * @user_data_free_func: function for freeing @user_data
+ *
+ * Binds @model to @self.
+ *
+ * See [method@Gtk.ListBox.bind_model].
+ *
+ * Since: 1.8
+ */
+void
+adw_preferences_group_bind_model (AdwPreferencesGroup        *self,
+                                  GListModel                 *model,
+                                  GtkListBoxCreateWidgetFunc  create_row_func,
+                                  gpointer                    user_data,
+                                  GDestroyNotify              user_data_free_func)
+{
+  AdwPreferencesGroupPrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_GROUP (self));
+  g_return_if_fail (model == NULL || G_IS_LIST_MODEL (model));
+  g_return_if_fail (model == NULL || create_row_func != NULL);
+
+  priv = adw_preferences_group_get_instance_private (self);
+
+  gtk_list_box_bind_model (priv->listbox, model, create_row_func, user_data, user_data_free_func);
+}
+
 /**
  * adw_preferences_group_get_rows:
  * @self: a preferences group
@@ -673,4 +733,3 @@ adw_preferences_group_get_rows (AdwPreferencesGroup *self)
 
   return model;
 }
-
